| Title: | Distributed Loading Estimation for General Factor Model |
|---|---|
| Description: | The load estimation method is based on a general factor model to solve the estimates of load and specific variance. The philosophy of the package is described in Guangbao Guo. (2022). <doi:10.1007/s00180-022-01270-z>. |
| Authors: | Guangbao Guo [aut, cre, cph], Yaping Li [aut] |
| Maintainer: | Guangbao Guo <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.4.0 |
| Built: | 2026-06-09 05:48:04 UTC |
| Source: | https://github.com/cran/DLEGFM |
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
BlPC(data,m)BlPC(data,m)
data |
The data is total data set |
m |
The m is the number of first layer principal component |
ABr |
estimation of load value |
ABc |
estimation of load value |
DBr |
estimation of error term |
DBc |
estimation of error term |
SigmaB1hat |
estimation of covariance |
SigmaB2hat |
estimation of covariance |
Guangbao Guo, Yaping Li
BlPC(data=ISE,m=3)BlPC(data=ISE,m=3)
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
DBlPC(data,m,n1,K)DBlPC(data,m,n1,K)
data |
The data is total data set |
m |
The m is the number of first layer principal component |
n1 |
The n1 is the length of each data subset |
K |
The K is the number of nodes |
ABr |
estimation of load value |
ABc |
estimation of load value |
DBr |
estimation of error term |
DBc |
estimation of error term |
SigmaB1hat |
estimation of covariance |
SigmaB2hat |
estimation of covariance |
Guangbao Guo, Yaping Li
DBlPC(data=ISE,m=3,n1=107,K=5)DBlPC(data=ISE,m=3,n1=107,K=5)
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
DFanPC(data,m,n1,K)DFanPC(data,m,n1,K)
data |
The data is total data set |
m |
The m is the number of principal component |
n1 |
The n1 is the length of each data subset |
K |
The K is the number of nodes |
AF |
estimation of load value |
DF |
estimation of error term |
SigmahatF |
estimation of covariance |
Guangbao Guo, Yaping Li
DFanPC(data=ISE,m=3,n1=107,K=5)DFanPC(data=ISE,m=3,n1=107,K=5)
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
DGaoPC(data,m,n1,K)DGaoPC(data,m,n1,K)
data |
The data is total data set |
m |
The m is the number of first layer principal component |
n1 |
The n1 is the length of each data subset |
K |
The K is the number of nodes |
AG1 |
estimation of load value |
AG2 |
estimation of load value |
DG1 |
estimation of error term |
DG2 |
estimation of error term |
SigmahatG1 |
estimation of covariance |
SigmahatG2 |
estimation of covariance |
Guangbao Guo, Yaping Li
DGaoPC(data=ISE,m=3,n1=107,K=5)DGaoPC(data=ISE,m=3,n1=107,K=5)
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
DGulPC(data,m,n1,K)DGulPC(data,m,n1,K)
data |
The data is total data set |
m |
The m is the number of first layer principal component |
n1 |
The n1 is the length of each data subset |
K |
The K is the number of nodes |
AU1 |
estimation of load value |
AU2 |
estimation of load value |
DU3 |
estimation of error term |
S1hat |
estimation of covariance |
Guangbao Guo, Yaping Li
DGulPC(data=ISE,m=3,n1=107,K=5)DGulPC(data=ISE,m=3,n1=107,K=5)
The Dow Jones industrial average (DJIA) data set.
data("DJIA")data("DJIA")
GAS.Fa numeric vector
Nikkei.Fa numeric vector
NZDa numeric vector
silver.Fa numeric vector
RUSSELL.Fa numeric vector
S.P.Fa numeric vector
CHFa numeric vector
Dollar.index.Fa numeric vector
Dollar.indexa numeric vector
wheat.Fa numeric vector
XAGa numeric vector
XAUa numeric vector
The data set comes from the Dow Jones industrial average (PSA) data of 96 patients collected by Stanford University Medical Center. These patients all underwent radical prostatectomy.
The Stanford University Medical Center.
NA
data(DJIA) ## maybe str(DJIA) ; plot(DJIA) ...data(DJIA) ## maybe str(DJIA) ; plot(DJIA) ...
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
DPC(data,m,n1,K)DPC(data,m,n1,K)
data |
The data is total data set |
m |
The m is the number of first layer principal component |
n1 |
The n1 is the length of each data subset |
K |
The K is the number of nodes |
Ahat |
estimation of load value |
Dhat |
estimation of error term |
Sigmahat |
estimation of covariance |
Guangbao Guo, Yaping Li
DPC(data=ISE,m=3,n1=107,K=5)DPC(data=ISE,m=3,n1=107,K=5)
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
DPPC(data,m,n1,K)DPPC(data,m,n1,K)
data |
The data is total data set |
m |
The m is the number of first layer principal component |
n1 |
The n1 is the length of each data subset |
K |
The K is the number of nodes |
Apro |
estimation of load value |
Dpro |
estimation of error term |
Sigmahatpro |
estimation of covariance |
Guangbao Guo, Yaping Li
DPPC(data=ISE,m=3,n1=107,K=5)DPPC(data=ISE,m=3,n1=107,K=5)
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
FanPC(data,m)FanPC(data,m)
data |
The data is total data set |
m |
The m is the number of principal component |
AF |
estimation of load value |
DF |
estimation of error term |
SigmahatF |
estimation of covariance |
Guangbao Guo, Yaping Li
FanPC(data=ISE,m=3)FanPC(data=ISE,m=3)
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
GaoPC(data,m)GaoPC(data,m)
data |
The data is total data set |
m |
The m is the number of principal component |
AG1 |
estimation of load value |
AG2 |
estimation of load value |
DG1 |
estimation of error term |
DG2 |
estimation of error term |
SigmahatG1 |
estimation of covariance |
SigmahatG2 |
estimation of covariance |
Guangbao Guo, Yaping Li
GaoPC(data=ISE,m=3)GaoPC(data=ISE,m=3)
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
GulPC(data,m)GulPC(data,m)
data |
The data is total data set |
m |
The m is the number of first layer principal component |
AU1 |
estimation of load value |
AU2 |
estimation of load value |
DU3 |
estimation of error term |
Shat |
estimation of covariance |
Guangbao Guo, Yaping Li
GulPC(data=ISE,m=3)GulPC(data=ISE,m=3)
The Istanbul Stock Exchange (ISE) data set.
data("ISE")data("ISE")
ISEa numeric vector
SPa numeric vector
DAXa numeric vector
FTSEa numeric vector
NIKKEIa numeric vector
BOVESPAa numeric vector
EUa numeric vector
EMa numeric vector
The data set comes from the Istanbul Stock Exchange (ISE) data of 96 patients collected by Stanford University Medical Center. These patients all underwent radical prostatectomy.
The Stanford University Medical Center.
NA
data(ISE) ## maybe str(ISE) ; plot(ISE) ...data(ISE) ## maybe str(ISE) ; plot(ISE) ...
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
PC(data,m)PC(data,m)
data |
The data is a highly correlated data set |
m |
The m is the number of principal component |
Ahat |
estimation of load value |
Dhat |
estimation of error term |
Sigmahat |
estimation of covariance |
Guangbao Guo, Yaping Li
PC(data=ISE,m=3)PC(data=ISE,m=3)
This function estimates the load and residual terms based on the general factor model and calculates the estimated values.
PPC(data,m)PPC(data,m)
data |
The data is total data set |
m |
The m is the number of principal component |
Apro |
estimation of load value |
Dpro |
estimation of error term |
Sigmahatpro |
estimation of covariance |
Guangbao Guo, Yaping Li
PPC(data=ISE,m=3)PPC(data=ISE,m=3)
The New York Stock Exchange Composite Index SECI(SECI) data set.
data("SECI")data("SECI")
GBPa numeric vector
JPYa numeric vector
CADa numeric vector
AAPLa numeric vector
AMZN a numeric vector
GEa numeric vector
JPMa numeric vector
MSFTa numeric vector
WFC a numeric vector
XOM a numeric vector
FCHI a numeric vector
FTSE a numeric vector
GDAXI a numeric vector
The data set comes from the prostate specific antigen (PSA) data of 96 patients collected by Stanford University Medical Center. These patients all underwent radical prostatectomy.
The Stanford University Medical Center.
NA
data(SECI) ## maybe str(SECI) ; plot(SECI) ...data(SECI) ## maybe str(SECI) ; plot(SECI) ...
The Stock Portfolio Performance (SPP) data set.
data("SPP")data("SPP")
X1a numeric vector
X2a numeric vector
X3a numeric vector
X4a numeric vector
X5a numeric vector
X6a numeric vector
X7a numeric vector
X8a numeric vector
X9a numeric vector
X10a numeric vector
The data set comes from the Stock Portfolio Performance (SPP) data of 96 patients collected by Stanford University Medical Center. These patients all underwent radical prostatectomy.
The Stanford University Medical Center.
NA
data(SPP) ## maybe str(SPP) ; plot(SPP) ...data(SPP) ## maybe str(SPP) ; plot(SPP) ...